@@ -1,6 +1,5 @@
 #pragma once
 #include <iostream>
-#include <mutex>
 #include <vector>
 
 #include "records.h"
@@ -13,7 +12,6 @@ class FrameTree
 
     inline std::pair<frame_id_t, index_t> nextNode(index_t index) const
     {
-        std::lock_guard<std::mutex> lock(d_mutex);
         assert(1 <= index && index <= d_graph.size());
         return std::make_pair(d_graph[index].frame_id, d_graph[index].parent_index);
     }
@@ -23,7 +21,6 @@ class FrameTree
     template<typename T>
     size_t getTraceIndex(const T& stack_trace, const tracecallback_t& callback)
     {
-        std::lock_guard<std::mutex> lock(d_mutex);
         index_t index = 0;
         for (const auto& frame : stack_trace) {
             index = getTraceIndexUnsafe(index, frame, callback);
@@ -33,7 +30,6 @@ class FrameTree
 
     size_t getTraceIndex(index_t parent_index, frame_id_t frame)
     {
-        std::lock_guard<std::mutex> lock(d_mutex);
         return getTraceIndexUnsafe(parent_index, frame, tracecallback_t());
     }
 
@@ -70,7 +66,6 @@ class FrameTree
         index_t parent_index;
         std::vector<DescendentEdge> children;
     };
-    mutable std::mutex d_mutex;
     std::vector<Node> d_graph{{0, 0, {}}};
 };
 }  // namespace memray::tracking_api
